#
# spec file for package freeglut
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _libname libglut3
Name:           freeglut
Version:        3.2.2
Release:        1.14
Summary:        Freely licensed alternative to the GLUT library
License:        MIT
URL:            http://freeglut.sourceforge.net/
Source:         https://downloads.sourceforge.net/project/freeglut/%{name}/%{version}/%{name}-%{version}.tar.gz
Source1:        https://downloads.sourceforge.net/openglut/openglut-0.6.3-doc.tar.gz
Source2:        baselibs.conf
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xxf86vm)
Recommends:     Mesa-demo-x
Provides:       mesaglut = 7.11
Obsoletes:      mesaglut < 7.11

%description
Freeglut is a completely open source alternative to the OpenGL Utility
Toolkit (GLUT) library. GLUT was originally written by Mark Kilgard to
support the sample programs in the second edition OpenGL Redbook. Since
then, GLUT has been used in a wide variety of practical applications
because it is simple, universally available, and highly portable.

GLUT (and freeglut) allow the user to create and manage windows
containing OpenGL contexts and also read the mouse, keyboard, and
joystick functions on a wide range of platforms.

%package -n %{_libname}
Summary:        Freely licensed alternative to the GLUT library

%description -n %{_libname}
Freeglut is a completely open source alternative to the OpenGL Utility
Toolkit (GLUT) library. GLUT was originally written by Mark Kilgard to
support the sample programs in the second edition OpenGL Redbook. Since
then, GLUT has been used in a wide variety of practical applications
because it is simple, universally available, and highly portable.

GLUT (and freeglut) allow the user to create and manage windows
containing OpenGL contexts and also read the mouse, keyboard, and
joystick functions on a wide range of platforms.

%package devel
Summary:        Development libraries, includes and man pages for freeglut (GLUT Library)
Requires:       %{_libname} = %{version}
Requires:       pkgconfig(gl)
Requires:       pkgconfig(glu)
Provides:       mesaglut-devel = 7.11
Obsoletes:      mesaglut-devel < 7.11

%description devel
This package contains all necessary include files and libraries needed
to compile and link applications for the freeglut library.

In addition, it also includes manual pages which describe all functions
provided by the freeglut library.

Freeglut is a completely open source alternative to the OpenGL Utility
Toolkit (GLUT) library. GLUT was originally written by Mark Kilgard to
support the sample programs in the second edition OpenGL Redbook. Since
then, GLUT has been used in a wide variety of practical applications
because it is simple, universally available, and highly portable.

GLUT (and freeglut) allow the user to create and manage windows
containing OpenGL contexts and also read the mouse, keyboard, and
joystick functions on a wide range of platforms.

%package demo
Summary:        Demonstration applications for the freeglut library

%description demo
This package contains demonstration applications for the freeglut library.

Freeglut is a completely open source alternative to the OpenGL Utility
Toolkit (GLUT) library. GLUT was originally written by Mark Kilgard to
support the sample programs in the second edition OpenGL Redbook. Since
then, GLUT has been used in a wide variety of practical applications
because it is simple, universally available, and highly portable.

GLUT (and freeglut) allow the user to create and manage windows
containing OpenGL contexts and also read the mouse, keyboard, and
joystick functions on a wide range of platforms.

%prep
%setup -q -a1

%build
%cmake \
    -DCMAKE_SKIP_RPATH=ON \
    -DFREEGLUT_BUILD_STATIC_LIBS=OFF
%cmake_build

%install
%cmake_install

# install demo files
install -d %{buildroot}%{_libexecdir}/freeglut
pushd build/bin/ > /dev/null
for i in *; do
    install $i %{buildroot}%{_libexecdir}/freeglut/$i
done
popd > /dev/null

# glut manpages
mkdir -p %{buildroot}/%{_mandir}/man3
install -p -m 644 doc/man/*.3 $RPM_BUILD_ROOT/%{_mandir}/man3

%post -n %{_libname} -p /sbin/ldconfig
%postun -n %{_libname} -p /sbin/ldconfig

%files -n %{_libname}
%license COPYING
%doc AUTHORS README
%{_libdir}/libglut.so.*

%files devel
%{_includedir}/GL
%{_libdir}/libglut.so
%{_libdir}/pkgconfig/glut.pc
%dir %{_libdir}/cmake/FreeGLUT
%{_libdir}/cmake/FreeGLUT/*
%{_mandir}/man3/*

%files demo
%{_libexecdir}/freeglut

%changelog
* Thu Mar 24 2022 Dirk Müller <dmueller@suse.com>
- update to 3.2.2:
  * Fix netbsd/aarch64 build by including sys/joystick.h instead of machine/joystick.h.
  * Fix build with gcc >= 10 which made -fno-common the default by no longer relying on COMMON symbols for globals.
  * Fix android build (default to FREEGLUT_GLES, and check for debug flags).
  * Add flat shading option to the shapes demo.
  * Fix crash when calling primitive drawing functions without creating a window first.
  * Dropped really old and unmaintained doc directory from the source tree.
- drop gcc10.patch (obsolete)
* Thu Mar 12 2020 Tomáš Chvátal <tchvatal@suse.com>
- Explicitely disable rpath to fix Leap builds
* Mon Mar  2 2020 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to fix build with GCC 10 bsc#1160391:
  * gcc10.patch
* Thu Jan  9 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.2.1:
  * Various fixes around the place that happened since last release
- Fetch the glut manpages from web to point them somewhere
* Fri Mar 13 2015 tchvatal@suse.com
- Version bump to 3.0.0
  * Now with cmake build system
  * Various small fixes around here and there - no upstream changelog
    apart from VCS
- Remove some more obsolete things from spec now when we use cmake
* Fri Mar 13 2015 tchvatal@suse.com
- Cleanup with spec-cleaner a bit
- Remove obsolete conditions
- Remove condition for sle11 build as it fails anyway
* Mon Sep 15 2014 crrodriguez@opensuse.org
- Cleanup buildrequires to include only what is actually
  used.
* Sat Apr  6 2013 meissner@suse.com
- Update to 2.8.1
  - bugfixes mostly, covering MacOS, Windows and also regular
    UNIX X code.
- use source url
- dropped upstreamed freeglut-glextconflict.patch
* Sun Mar 24 2013 jengelh@inai.de
- freeglut only directly depends on gl/glu, nothing else
* Sun Mar  3 2013 jengelh@inai.de
- Use more robust make install call which also works on SLE
  and others
* Tue Sep 18 2012 coolo@suse.com
- add patch from fedora to fix build with latest GL stack:
  freeglut-glextconflict.patch
* Tue Sep 18 2012 coolo@suse.com
- in 12.3 libGLU is no longer part of Mesa
* Sun May 13 2012 mlin@suse.com
- Rename invalid package name Mesa-demos-base to Mesa-demo-x
* Wed Feb 29 2012 tabraham@novell.com
- Update to 2.8.0
  * There are now callbacks to support multitouch capability.
  * Solaris and OSX support have improved.
  * Fullscreen mode and Game mode behave better.
  * Addition of Visual Studio 2010 projects & solutions.
  * Many bugs have been fixed.
* Mon Feb 13 2012 coolo@suse.com
- fix baselibs.conf for devel-32bit
* Fri Jan 27 2012 saschpe@gmx.de
- Rename demos package to freeglut-demo to match other demo packages
- Honor shared library policy:
  * Rename base package to libglut3 and adjust baselibs.conf accordingly
- Ran spec-cleaner
* Tue Nov 15 2011 johannesobermayr@gmx.de
- Update to pre-2.8.0 git
  * Use a prefixed version (2.7.99)
- Install already built demos
  * Add -demos subpackage
- Remove obsolete compat70.tar.bz2
- glxgears, xdriinfo and glxinfo are part of Mesa-demos-base
  * Remove glxdemos.tar.bz2, glxdemos.diff, xdriinfo.tar.bz2
    freeglut-glxgears.notify.diff and freeglut-glxinfo.notify.diff
* Sat Oct  1 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Tue Nov  9 2010 sndirsch@novell.com
- xdriinfo 1.0.4
  * This minor maintenance release provides the usual recent
    collection of build configuration improvements and janitorial
    cleanups.
* Tue Aug 31 2010 sndirsch@suse.de
- switched to current freeglut sources in SVN (2010-05-29);
  hopefully also fixes bnc #635821
* Sun Apr  4 2010 sndirsch@suse.de
- xdriinfo 1.0.3
* Wed Dec 16 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Tue Apr 21 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Tue Mar  3 2009 sndirsch@suse.de
- switched to current freeglut sources in SVN (2009-03-01)
- obsoletes freeglut-080721.diff, freeglut-sig11-bug466806.diff
* Tue Jan 20 2009 mhopf@suse.de
- freeglut-glxgears-notify.diff, freeglut-glxinfo-notify.diff
  * Notify user if direct rendering or hardware acceleration
    is not available
  * Notify user that glxgears is not a benchmark
* Sat Jan 17 2009 sndirsch@suse.de
- freeglut-sig11-bug466806.diff
  * fix Sig11 in glutCreateWindow() for GLX drivers < 1.3
    (bnc #466806)
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Mon Aug 11 2008 sndirsch@suse.de
- switched to current freeglut sources in SVN (2008-07-21):
  * Changed "fgStructure.GameMode" to "fgStructure.GameModeWindow"
    to reflect better what it is
  * Added an end-of-line character to a warning message about an
    unknown X event type
  * Fixing a problem in which "glutGetWindow" would return a menu's
    window instead of the menu's parent window
  * Added some handy comments, spacing, fixed a typo in a comment
  * Changed "TARGET_HOST_UNIX_X11" to "TARGET_HOST_POSIX_X11" to
    avoid trademark issues, per Joe Krahn; also rationalized the
    other "TARGET_HOST" definitions
  * Added futher callback functionality to the CallbackMaker demo
    program.  Also added a prompt for user input to highlight a
    difference betwen GLUT and "freeglut"
  * Added multisampling support for *nix and Windows; some other
    pixel format changes for Windows
  * Added Markus Henschel's change (e-mail to developers' list,
    June 28, 2006) to have the "glutInitDisplayString" ignore
    numerical assignments to tokens as a temporary fix.
  * Fixed buy #1398196 in the bug tracker to the effect that
    passing the wrong argument in "fghSleepForEvents" can cause
    odd delays
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Sat Aug 18 2007 sndirsch@suse.de
- xdriinfo 1.0.2
  * X.Org bug #10616: Add all the X info commands to See Also in
    man page
* Sun Sep  3 2006 sndirsch@suse.de
- update to current CVS (2006-09-03)
  * Check fgets for return value to avoid warnings
* Sun Jul 23 2006 sndirsch@suse.de
- updated xdriinfo
- fixed build for X.Org 7
* Thu Jan 26 2006 mls@suse.de
- fix BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Nov 11 2005 sndirsch@suse.de
- moved glxinfo/glxgears/xdriinfo from -devel to main package
* Thu Nov 10 2005 sndirsch@suse.de
- updated to current CVS (05-11-10) to fix all these "freeglut
  ERROR: Function <glut<whatever>> called without first calling
  'glutInit'" errors, which prevented many programs from starting
  (e.g. FlightGear); freeglut 2.4 seems known to be broken :-(
* Mon Nov  7 2005 sndirsch@suse.de
- switched to external built Mesa
* Wed Oct 26 2005 sndirsch@suse.de
- added build of glxinfo/glxgears/xdriinfo when %%USE_EXTERNAL_MESA
  is set
* Fri Jun 24 2005 sndirsch@suse.de
- update to final release 2.4.0
* Fri Jun 10 2005 sndirsch@suse.de
- removed "-Werror"
* Mon Jun  6 2005 sndirsch@suse.de
- update to release 2.4.0-rc4
- obsoletes freeglut-gcc4.diff
* Sun Apr 10 2005 sndirsch@suse.de
- new gcc4 patch (use the bits of CVS)
* Thu Apr  7 2005 meissner@suse.de
- fortran does not appear to be needed here (just libtool
  checks for it as standard).
* Sat Apr  2 2005 coolo@suse.de
- fix casts
* Thu Apr 29 2004 coolo@suse.de
- build parallel if available
- build as user
* Mon Dec 15 2003 sndirsch@suse.de
- updated to release 2.2.0
  * Mousewheel Support for Win32 & X11
  * More unified Win32/*nix behavior and code
  * Code style cleanups
  * Visibility support in Win32
  * Many other Good Bug Fixes
* Sat Dec  6 2003 sndirsch@suse.de
- updated to release 2.0.1
  * fixes a number of bugs with menus
* Fri Oct 10 2003 adrian@suse.de
- fix build for mips
- satisfy configure checks
* Thu Oct  2 2003 sndirsch@suse.de
- provides/obsoletes mesaglut/mesglut-devel now
* Tue Sep 30 2003 sndirsch@suse.de
- removed demos
* Tue Sep 30 2003 sndirsch@suse.de
- added GLUT manual pages
* Mon Sep 29 2003 sndirsch@suse.de
- updated to final release 2.0.0
* Thu Aug 14 2003 sndirsch@suse.de
- added GameMode fix (GameModeFixes-4.dif)
* Thu Aug  7 2003 sndirsch@suse.de
- created package
